@@ -136,13 +136,12 @@ Dialog::Dialog(QWidget *parent) :
         const auto primaryScreen = QGuiApplication::primaryScreen();
         if (primaryScreen != nullptr)
             connect(primaryScreen, &QScreen::availableGeometryChanged, this, &Dialog::realign);
+        resize(mSettings->value(QL1S("dialog/width"), 400).toInt(), size().height());
     }
 
     connect(mGlobalShortcut, &GlobalKeyShortcut::Action::activated, this, &Dialog::showHide);
     connect(mGlobalShortcut, &GlobalKeyShortcut::Action::shortcutChanged, this, &Dialog::shortcutChanged);
 
-    resize(mSettings->value(QL1S("dialog/width"), 400).toInt(), size().height());
-
     // TEST
     connect(mCommandItemModel, &CommandItemModel::layoutChanged, this, &Dialog::dataChanged);
 }
@@ -183,8 +182,9 @@ QSize Dialog::sizeHint() const
  ************************************************/
 void Dialog::resizeEvent(QResizeEvent *event)
 {
-    if (event->spontaneous())
+    if (event->spontaneous() && QGuiApplication::platformName() != QSL("wayland"))
         mSettings->setValue(QL1S("dialog/width"), size().width());
+    QDialog::resizeEvent(event);
 }
 
 
@@ -219,40 +219,75 @@ void Dialog::showEvent(QShowEvent *event)
             {
                 layershell->setLayer(LayerShellQt::Window::Layer::LayerTop);
                 layershell->setKeyboardInteractivity(LayerShellQt::Window::KeyboardInteractivityOnDemand);
-                LayerShellQt::Window::Anchors anchors = {LayerShellQt::Window::AnchorTop};
-                layershell->setScope(QStringLiteral("launcher"));
+                LayerShellQt::Window::Anchors anchors = {LayerShellQt::Window::AnchorTop
+                                                         | LayerShellQt::Window::AnchorLeft
+                                                         | LayerShellQt::Window::AnchorRight};
                 layershell->setAnchors(anchors);
+                layershell->setScope(QStringLiteral("launcher"));
 
+                bool onCursorScreen(false);
                 QScreen *screen = nullptr;
                 const auto screens = QGuiApplication::screens();
-                if (mMonitor >= 0 && mMonitor < screens.size())
-                    screen = screens.at(mMonitor);
+                for (int i = 0; i < screens.size(); ++i)
+                {
+                    if (screens.at(i)->name() == mScreenName)
+                    {
+                        screen = screens.at(i);
+                        break;
+                    }
+                }
                 if (screen)
                 {
                     win->setScreen(screen);
+                    if (auto parent = parentWidget())
+                    {
+                        parent->setScreen(screen);
+                    }
                     layershell->setScreenConfiguration(LayerShellQt::Window::ScreenConfiguration::ScreenFromQWindow);
                 }
                 else
                 { // the screen is not set by us; leave it to the compositor
+                    onCursorScreen = true;
                     layershell->setScreenConfiguration(LayerShellQt::Window::ScreenConfiguration::ScreenFromCompositor);
                     // get the screen that the compositor chooses
                     screen = windowHandle()->screen();
                 }
 
-                if (mShowOnTop)
+                int topMargin = mTopMargin;
+                int hMragin = 0;
+                if (screen)
                 {
-                    layershell->setMargins(QMargins(0, mTopMargin, 0, 0));
-                }
-                else if (screen)
-                {
-                    QRect desktop = screen->availableGeometry();
-                    int topMargin = desktop.center().y() - ui->panel->sizeHint().height();
-                    layershell->setMargins(QMargins(0, topMargin, 0, 0));
+                    QSize aSize = screen->availableGeometry().size();
+                    // NOTE: Since QShowEvent is non-spontaneous here, the window is not shown yet,
+                    // and so, this screen may not be the one with the cursor. Unfortunately, Qt
+                    // provides no way of knowing the screen with the cursor. Therefore, to prevent
+                    // an offscreen window, we should find the smallest geometry and set the
+                    // margins by considering it, at the cost of a wider window on the other
+                    // screens and positioning it above their centers.
+                    if (onCursorScreen)
+                    {
+                        for (const auto &screen : screens)
+                        {
+                            aSize = aSize.boundedTo(screen->availableGeometry().size());
+                        }
+                        if (mShowOnTop)
+                        {
+                            topMargin = qMin(topMargin, aSize.height() - ui->panel->sizeHint().height());
+                        }
+                    }
+                    int w = qBound(400, aSize.width() * mWaylandWidth / 100, aSize.width());
+                    setFixedWidth(w);
+                    hMragin = qMax((aSize.width() - w), 0) / 2;
+                    if (!mShowOnTop)
+                    {
+                        topMargin = qMax(aSize.height() / 2 - ui->panel->sizeHint().height(), 0);
+                    }
                 }
+                layershell->setMargins(QMargins(hMragin, topMargin, hMragin, 0));
             }
         }
     }
-    else
+    else if (QGuiApplication::platformName() == QSL("xcb"))
     {
         connect(KX11Extras::self(), &KX11Extras::activeWindowChanged, this, &Dialog::onActiveWindowChanged);
         connect(KX11Extras::self(), &KX11Extras::currentDesktopChanged, this, &Dialog::onCurrentDesktopChanged);
@@ -339,6 +374,10 @@ bool Dialog::editKeyPressEvent(QKeyEvent *event)
             setFilter(QString(), false);
             return true;
         }
+        if (event->key() == Qt::Key_Home && !event->modifiers().testFlag(Qt::ControlModifier))
+        { // Use Home key without Ctrl inside the editor
+            return QDialog::eventFilter(ui->commandEd, event);
+        }
         qApp->sendEvent(ui->commandList, event);
         return true;
 
@@ -357,6 +396,10 @@ bool Dialog::editKeyPressEvent(QKeyEvent *event)
             ui->commandEd->setFocus();
             return true;
         }
+        if (event->key() == Qt::Key_End && !event->modifiers().testFlag(Qt::ControlModifier))
+        { // Use End key without Ctrl inside the editor
+            return QDialog::eventFilter(ui->commandEd, event);
+        }
         qApp->sendEvent(ui->commandList, event);
         return true;
 
@@ -487,6 +530,23 @@ void Dialog::applySettings()
     mClearOnRunning = mSettings->value(QL1S("dialog/clear_on_running"), true).toBool();
 
     mMonitor = mSettings->value(QL1S("dialog/monitor"), -1).toInt();
+    if (QGuiApplication::platformName() == QSL("wayland"))
+    {
+        mScreenName = mSettings->value(QL1S("dialog/screen_name")).toString();
+        if (mScreenName.isEmpty() && mMonitor >= 0)
+        {
+            const auto screens = QGuiApplication::screens();
+            if (mMonitor < screens.size())
+            {
+                mScreenName = screens.at(mMonitor)->name();
+                // save the found name
+                QTimer::singleShot(3000, mSettings, [this] {
+                    mSettings->setValue(QL1S("dialog/screen_name"), mScreenName);
+                });
+            }
+        }
+        mWaylandWidth = mSettings->value(QL1S("dialog/wayland_width")).toInt();
+    }
 
     mCommandItemModel->setUseHistory(mSettings->value(QL1S("dialog/history_use"), true).toBool());
     mCommandItemModel->showHistoryFirst(mSettings->value(QL1S("dialog/history_first"), true).toBool());
@@ -636,11 +696,34 @@ void Dialog::showConfigDialog()
  ************************************************/
 bool Dialog::event(QEvent *event)
 {
-    // On Wayland, the workaround related to mDesktopChanged does not make sense because
-    // we cannot activate any window. So, we just hide the window on deactivation.
-    if (event->type() == QEvent::WindowDeactivate && QGuiApplication::platformName() != QSL("xcb"))
+    if (QGuiApplication::platformName() == QSL("wayland"))
     {
-        hide();
+        if (event->type() == QEvent::WindowDeactivate)
+        {
+            // On Wayland, the workaround related to mDesktopChanged does not make sense because
+            // we cannot activate any window. So, we just hide the window on deactivation.
+            hide();
+        }
+        else if (event->type() == QEvent::Hide || event->type() == QEvent::Show)
+        {
+            // Show or hide the window with the Wayland shortcut, imitating Dialog::showHide.
+            static bool isHidden = true;
+            if (event->type() == QEvent::Hide)
+            {
+                isHidden = true;
+            }
+            else
+            {
+                if (!isHidden && !event->spontaneous())
+                { // hide the window after consuming the event
+                    QTimer::singleShot(0, this, [this] {hide();});
+                    return true;
+                }
+                isHidden = false;
+                ui->commandEd->setFocus();
+                ui->commandEd->selectAll();
+            }
+        }
     }
     return QDialog::event(event);
 }
