@@ -81,6 +81,8 @@ private:
     int mTopMargin;
     bool mClearOnRunning;
     int mMonitor;
+    QString mScreenName;
+    int mWaylandWidth;
     LXQt::PowerManager *mPowerManager;
     LXQt::ScreenSaver *mScreenSaver;
 
